/*
 * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class LocaleNames_zgh extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "AD", "\u2d30\u2d4f\u2d37\u2d53\u2d54\u2d30" },
            { "AE", "\u2d4d\u2d49\u2d4e\u2d30\u2d54\u2d30\u2d5c" },
            { "AF", "\u2d30\u2d3c\u2d56\u2d30\u2d4f\u2d49\u2d59\u2d5c\u2d30\u2d4f" },
            { "AG", "\u2d30\u2d4f\u2d5c\u2d49\u2d33\u2d30 \u2d37 \u2d31\u2d54\u2d31\u2d53\u2d37\u2d30" },
            { "AI", "\u2d30\u2d4f\u2d33\u2d49\u2d4d\u2d30" },
            { "AL", "\u2d30\u2d4d\u2d31\u2d30\u2d4f\u2d62\u2d30" },
            { "AM", "\u2d30\u2d54\u2d4e\u2d49\u2d4f\u2d62\u2d30" },
            { "AO", "\u2d30\u2d4f\u2d33\u2d53\u2d4d\u2d30" },
            { "AR", "\u2d30\u2d54\u2d4a\u2d30\u2d4f\u2d5c\u2d49\u2d4f" },
            { "AS", "\u2d59\u2d30\u2d4e\u2d61\u2d30 \u2d5c\u2d30\u2d4e\u2d49\u2d54\u2d49\u2d3d\u2d30\u2d4f\u2d49\u2d5c" },
            { "AT", "\u2d4f\u2d4f\u2d4e\u2d59\u2d30" },
            { "AU", "\u2d53\u2d59\u2d5c\u2d54\u2d30\u2d4d\u2d62\u2d30" },
            { "AW", "\u2d30\u2d54\u2d53\u2d31\u2d30" },
            { "AZ", "\u2d30\u2d37\u2d54\u2d30\u2d31\u2d49\u2d4a\u2d30\u2d4f" },
            { "BA", "\u2d31\u2d53\u2d59\u2d4f\u2d30 \u2d37 \u2d40\u2d49\u2d54\u2d59\u2d49\u2d3d" },
            { "BB", "\u2d31\u2d30\u2d54\u2d31\u2d30\u2d37" },
            { "BD", "\u2d31\u2d30\u2d4f\u2d33\u2d4d\u2d30\u2d37\u2d49\u2d5b" },
            { "BE", "\u2d31\u2d4d\u2d4a\u2d49\u2d3d\u2d30" },
            { "BF", "\u2d31\u2d53\u2d54\u2d3d\u2d49\u2d4f\u2d30 \u2d3c\u2d30\u2d59\u2d53" },
            { "BG", "\u2d31\u2d4d\u2d56\u2d30\u2d54\u2d62\u2d30" },
            { "BH", "\u2d31\u2d43\u2d54\u2d30\u2d62\u2d4f" },
            { "BI", "\u2d31\u2d53\u2d54\u2d53\u2d4f\u2d37\u2d49" },
            { "BJ", "\u2d31\u2d49\u2d4f\u2d49\u2d4f" },
            { "BM", "\u2d31\u2d54\u2d4e\u2d53\u2d37\u2d30" },
            { "BN", "\u2d31\u2d54\u2d53\u2d4f\u2d49" },
            { "BO", "\u2d31\u2d53\u2d4d\u2d49\u2d31\u2d62\u2d30" },
            { "BR", "\u2d31\u2d54\u2d30\u2d63\u2d49\u2d4d" },
            { "BS", "\u2d31\u2d30\u2d40\u2d30\u2d4e\u2d30\u2d59" },
            { "BT", "\u2d31\u2d40\u2d53\u2d5c\u2d30\u2d4f" },
            { "BW", "\u2d31\u2d53\u2d5c\u2d59\u2d61\u2d30\u2d4f\u2d30" },
            { "BY", "\u2d31\u2d49\u2d4d\u2d30\u2d54\u2d53\u2d59\u2d62\u2d30" },
            { "BZ", "\u2d31\u2d49\u2d4d\u2d49\u2d63" },
            { "CA", "\u2d3d\u2d30\u2d4f\u2d30\u2d37\u2d30" },
            { "CD", "\u2d5c\u2d30\u2d33\u2d37\u2d53\u2d37\u2d30\u2d4f\u2d5c \u2d5c\u2d30\u2d37\u2d49\u2d4e\u2d53\u2d47\u2d54\u2d30\u2d5c\u2d49\u2d5c \u2d4f \u2d3d\u2d53\u2d4f\u2d33\u2d53" },
            { "CF", "\u2d5c\u2d30\u2d33\u2d37\u2d53\u2d37\u2d30\u2d4f\u2d5c \u2d5c\u2d30\u2d4f\u2d30\u2d4e\u2d4e\u2d30\u2d59\u2d5c \u2d4f \u2d49\u2d3c\u2d54\u2d49\u2d47\u2d62\u2d30" },
            { "CG", "\u2d3d\u2d53\u2d4f\u2d33\u2d53" },
            { "CH", "\u2d59\u2d61\u2d49\u2d59\u2d54\u2d30" },
            { "CI", "\u2d3d\u2d53\u2d5c \u2d37\u2d49\u2d3c\u2d61\u2d30\u2d54" },
            { "CK", "\u2d5c\u2d49\u2d33\u2d63\u2d49\u2d54\u2d49\u2d4f \u2d4f \u2d3d\u2d53\u2d3d" },
            { "CL", "\u2d5b\u2d5b\u2d49\u2d4d\u2d49" },
            { "CM", "\u2d3d\u2d30\u2d4e\u2d49\u2d54\u2d53\u2d4f" },
            { "CN", "\u2d5b\u2d5b\u2d49\u2d4f\u2d61\u2d30" },
            { "CO", "\u2d3d\u2d53\u2d4d\u2d53\u2d4e\u2d31\u2d62\u2d30" },
            { "CR", "\u2d3d\u2d53\u2d59\u2d5c\u2d30 \u2d54\u2d49\u2d3d\u2d30" },
            { "CU", "\u2d3d\u2d53\u2d31\u2d30" },
            { "CV", "\u2d5c\u2d49\u2d33\u2d63\u2d49\u2d54\u2d49\u2d4f \u2d4f \u2d3d\u2d30\u2d31\u2d31\u2d49\u2d54\u2d37\u2d49" },
            { "CY", "\u2d47\u2d53\u2d31\u2d54\u2d53\u2d59" },
            { "CZ", "\u2d5c\u2d30\u2d33\u2d37\u2d53\u2d37\u2d30\u2d4f\u2d5c \u2d5c\u2d30\u2d5c\u2d5b\u2d49\u2d3d\u2d49\u2d5c" },
            { "DE", "\u2d30\u2d4d\u2d4e\u2d30\u2d4f\u2d62\u2d30" },
            { "DJ", "\u2d37\u2d4a\u2d49\u2d31\u2d53\u2d5c\u2d49" },
            { "DK", "\u2d37\u2d30\u2d4f\u2d4e\u2d30\u2d54\u2d3d" },
            { "DM", "\u2d37\u2d53\u2d4e\u2d49\u2d4f\u2d49\u2d3d" },
            { "DO", "\u2d5c\u2d30\u2d33\u2d37\u2d53\u2d37\u2d30\u2d4f\u2d5c \u2d5c\u2d30\u2d37\u2d53\u2d4e\u2d49\u2d4f\u2d49\u2d3d\u2d5c" },
            { "DZ", "\u2d37\u2d63\u2d30\u2d62\u2d54" },
            { "EC", "\u2d49\u2d3d\u2d61\u2d30\u2d37\u2d53\u2d54" },
            { "EE", "\u2d49\u2d59\u2d5c\u2d53\u2d4f\u2d62\u2d30" },
            { "EG", "\u2d4e\u2d49\u2d5a\u2d55" },
            { "ER", "\u2d49\u2d54\u2d49\u2d5c\u2d49\u2d54\u2d62\u2d30" },
            { "ES", "\u2d59\u2d31\u2d30\u2d4f\u2d62\u2d30" },
            { "ET", "\u2d49\u2d5c\u2d62\u2d53\u2d31\u2d62\u2d30" },
            { "FI", "\u2d3c\u2d49\u2d4d\u2d4d\u2d30\u2d4f\u2d37\u2d30" },
            { "FJ", "\u2d3c\u2d49\u2d37\u2d4a\u2d49" },
            { "FK", "\u2d5c\u2d49\u2d33\u2d63\u2d49\u2d54\u2d49\u2d4f \u2d4f \u2d4e\u2d30\u2d4d\u2d30\u2d61\u2d49" },
            { "FM", "\u2d4e\u2d49\u2d3d\u2d54\u2d53\u2d4f\u2d49\u2d63\u2d62\u2d30" },
            { "FR", "\u2d3c\u2d54\u2d30\u2d4f\u2d59\u2d30" },
            { "GA", "\u2d33\u2d30\u2d31\u2d53\u2d4f" },
            { "GB", "\u2d5c\u2d30\u2d33\u2d4d\u2d37\u2d49\u2d5c \u2d49\u2d4e\u2d53\u2d4f\u2d4f" },
            { "GD", "\u2d56\u2d54\u2d4f\u2d30\u2d5f\u2d30" },
            { "GE", "\u2d4a\u2d53\u2d54\u2d4a\u2d62\u2d30" },
            { "GF", "\u2d33\u2d61\u2d49\u2d62\u2d30\u2d4f \u2d5c\u2d30\u2d3c\u2d54\u2d30\u2d4f\u2d59\u2d49\u2d59\u2d5c" },
            { "GH", "\u2d56\u2d30\u2d4f\u2d30" },
            { "GI", "\u2d30\u2d37\u2d54\u2d30\u2d54 \u2d4f \u2d5f\u2d30\u2d55\u2d49\u2d47" },
            { "GL", "\u2d33\u2d54\u2d49\u2d4d\u2d30\u2d4f\u2d37" },
            { "GM", "\u2d33\u2d30\u2d4e\u2d31\u2d62\u2d30" },
            { "GN", "\u2d56\u2d49\u2d4f\u2d62\u2d30" },
            { "GP", "\u2d33\u2d61\u2d30\u2d37\u2d30\u2d4d\u2d53\u2d31" },
            { "GQ", "\u2d56\u2d49\u2d4f\u2d62\u2d30 \u2d4f \u2d49\u2d3d\u2d61\u2d30\u2d37\u2d53\u2d54" },
            { "GR", "\u2d4d\u2d62\u2d53\u2d4f\u2d30\u2d4f" },
            { "GT", "\u2d33\u2d61\u2d30\u2d5c\u2d49\u2d4e\u2d30\u2d4d\u2d30" },
            { "GU", "\u2d33\u2d61\u2d30\u2d4e" },
            { "GW", "\u2d56\u2d49\u2d4f\u2d62\u2d30 \u2d31\u2d49\u2d59\u2d30\u2d61" },
            { "GY", "\u2d33\u2d61\u2d49\u2d62\u2d30\u2d4f\u2d30" },
            { "HN", "\u2d40\u2d53\u2d4f\u2d37\u2d53\u2d54\u2d30\u2d59" },
            { "HR", "\u2d3d\u2d54\u2d61\u2d30\u2d5c\u2d62\u2d30" },
            { "HT", "\u2d40\u2d30\u2d62\u2d5c\u2d49" },
            { "HU", "\u2d40\u2d4f\u2d56\u2d30\u2d54\u2d62\u2d30" },
            { "ID", "\u2d30\u2d4f\u2d37\u2d53\u2d4f\u2d49\u2d59\u2d62\u2d30" },
            { "IE", "\u2d49\u2d54\u2d4d\u2d30\u2d4f\u2d37\u2d30" },
            { "IL", "\u2d49\u2d59\u2d54\u2d30\u2d62\u2d49\u2d4d" },
            { "IN", "\u2d4d\u2d40\u2d49\u2d4f\u2d37" },
            { "IO", "\u2d5c\u2d30\u2d4e\u2d4f\u2d30\u2d39\u2d5c \u2d5c\u2d30\u2d4f\u2d33\u2d4d\u2d49\u2d63\u2d49\u2d5c \u2d4f \u2d53\u2d33\u2d30\u2d54\u2d53 \u2d30\u2d40\u2d49\u2d4f\u2d37\u2d49" },
            { "IQ", "\u2d4d\u2d44\u2d49\u2d54\u2d30\u2d47" },
            { "IR", "\u2d49\u2d54\u2d30\u2d4f" },
            { "IS", "\u2d49\u2d59\u2d4d\u2d30\u2d4f\u2d37" },
            { "IT", "\u2d49\u2d5f\u2d30\u2d4d\u2d62\u2d30" },
            { "JM", "\u2d4a\u2d30\u2d4e\u2d30\u2d62\u2d3d\u2d30" },
            { "JO", "\u2d4d\u2d53\u2d54\u2d37\u2d53\u2d4f" },
            { "JP", "\u2d4d\u2d62\u2d30\u2d31\u2d30\u2d4f" },
            { "KE", "\u2d3d\u2d49\u2d4f\u2d62\u2d30" },
            { "KG", "\u2d3d\u2d49\u2d54\u2d56\u2d49\u2d63\u2d49\u2d59\u2d5c\u2d30\u2d4f" },
            { "KH", "\u2d3d\u2d30\u2d4e\u2d31\u2d53\u2d37\u2d62\u2d30" },
            { "KI", "\u2d3d\u2d49\u2d54\u2d49\u2d31\u2d30\u2d5c\u2d49" },
            { "KM", "\u2d47\u2d53\u2d4e\u2d53\u2d54" },
            { "KN", "\u2d59\u2d30\u2d4f\u2d3d\u2d54\u2d49\u2d59 \u2d37 \u2d4f\u2d49\u2d3c\u2d49\u2d59" },
            { "KP", "\u2d3d\u2d53\u2d54\u2d62\u2d30 \u2d4f \u2d49\u2d65\u2d65\u2d4d\u2d4e\u2d39" },
            { "KR", "\u2d3d\u2d53\u2d54\u2d62\u2d30 \u2d4f \u2d49\u2d3c\u2d3c\u2d53\u2d59" },
            { "KW", "\u2d4d\u2d3d\u2d61\u2d49\u2d5c" },
            { "KY", "\u2d5c\u2d49\u2d33\u2d63\u2d49\u2d54\u2d49\u2d4f \u2d4f \u2d3d\u2d30\u2d62\u2d4e\u2d30\u2d4f" },
            { "KZ", "\u2d3d\u2d30\u2d63\u2d30\u2d45\u2d59\u2d5c\u2d30\u2d4f" },
            { "LA", "\u2d4d\u2d30\u2d61\u2d59" },
            { "LB", "\u2d4d\u2d53\u2d31\u2d4f\u2d30\u2d4f" },
            { "LC", "\u2d59\u2d30\u2d4f\u2d5c\u2d4d\u2d53\u2d59\u2d49" },
            { "LI", "\u2d4d\u2d49\u2d3d\u2d49\u2d4f\u2d5b\u2d5c\u2d30\u2d62\u2d4f" },
            { "LK", "\u2d59\u2d54\u2d49\u2d4d\u2d30\u2d4f\u2d3d\u2d30" },
            { "LR", "\u2d4d\u2d49\u2d31\u2d49\u2d54\u2d62\u2d30" },
            { "LS", "\u2d4d\u2d49\u2d5a\u2d53\u2d5f\u2d53" },
            { "LT", "\u2d4d\u2d49\u2d5c\u2d61\u2d30\u2d4f\u2d62\u2d30" },
            { "LU", "\u2d4d\u2d53\u2d3d\u2d59\u2d30\u2d4f\u2d31\u2d53\u2d54\u2d33" },
            { "LV", "\u2d4d\u2d30\u2d5c\u2d3c\u2d62\u2d30" },
            { "LY", "\u2d4d\u2d49\u2d31\u2d62\u2d30" },
            { "MA", "\u2d4d\u2d4e\u2d56\u2d54\u2d49\u2d31" },
            { "MC", "\u2d4e\u2d53\u2d4f\u2d30\u2d3d\u2d53" },
            { "MD", "\u2d4e\u2d53\u2d4d\u2d37\u2d53\u2d3c\u2d62\u2d30" },
            { "ME", "\u2d4e\u2d53\u2d4f\u2d5c\u2d49\u2d4f\u2d49\u2d33\u2d54\u2d53" },
            { "MG", "\u2d4e\u2d30\u2d37\u2d30\u2d56\u2d30\u2d5b\u2d47\u2d30\u2d54" },
            { "MH", "\u2d5c\u2d49\u2d33\u2d63\u2d49\u2d54\u2d49\u2d4f \u2d4f \u2d4e\u2d30\u2d54\u2d5b\u2d30\u2d4d" },
            { "ML", "\u2d4e\u2d30\u2d4d\u2d49" },
            { "MM", "\u2d4e\u2d62\u2d30\u2d4f\u2d4e\u2d30\u2d54" },
            { "MN", "\u2d4e\u2d4f\u2d56\u2d53\u2d4d\u2d62\u2d30" },
            { "MP", "\u2d5c\u2d49\u2d33\u2d63\u2d49\u2d54\u2d49\u2d4f \u2d4f \u2d4e\u2d30\u2d54\u2d62\u2d30\u2d4f \u2d4f \u2d49\u2d65\u2d65\u2d4d\u2d4e\u2d39" },
            { "MQ", "\u2d4e\u2d30\u2d54\u2d5c\u2d49\u2d4f\u2d49\u2d3d" },
            { "MR", "\u2d4e\u2d53\u2d55\u2d49\u2d5f\u2d30\u2d4f\u2d62\u2d30" },
            { "MS", "\u2d4e\u2d53\u2d4f\u2d59\u2d49\u2d54\u2d30\u2d5c" },
            { "MT", "\u2d4e\u2d30\u2d4d\u2d5f\u2d30" },
            { "MU", "\u2d4e\u2d53\u2d54\u2d49\u2d59" },
            { "MV", "\u2d4e\u2d30\u2d4d\u2d37\u2d49\u2d3c" },
            { "MW", "\u2d4e\u2d30\u2d4d\u2d30\u2d61\u2d49" },
            { "MX", "\u2d4e\u2d49\u2d3d\u2d59\u2d49\u2d3d" },
            { "MY", "\u2d4e\u2d30\u2d4d\u2d49\u2d63\u2d62\u2d30" },
            { "MZ", "\u2d4e\u2d53\u2d63\u2d4f\u2d31\u2d49\u2d47" },
            { "NA", "\u2d4f\u2d30\u2d4e\u2d49\u2d31\u2d62\u2d30" },
            { "NC", "\u2d3d\u2d30\u2d4d\u2d49\u2d37\u2d53\u2d4f\u2d62\u2d30 \u2d5c\u2d30\u2d4e\u2d30\u2d62\u2d4f\u2d53\u2d5c" },
            { "NE", "\u2d4f\u2d4f\u2d49\u2d4a\u2d49\u2d54" },
            { "NF", "\u2d5c\u2d49\u2d33\u2d63\u2d49\u2d54\u2d49\u2d4f \u2d4f \u2d4f\u2d53\u2d54\u2d3c\u2d53\u2d4d\u2d3d" },
            { "NG", "\u2d4f\u2d49\u2d4a\u2d49\u2d54\u2d62\u2d30" },
            { "NI", "\u2d4f\u2d49\u2d3d\u2d30\u2d54\u2d30\u2d33\u2d61\u2d30" },
            { "NL", "\u2d40\u2d53\u2d4d\u2d30\u2d4f\u2d37\u2d30" },
            { "NO", "\u2d4f\u2d4f\u2d54\u2d61\u2d49\u2d4a" },
            { "NP", "\u2d4f\u2d49\u2d31\u2d30\u2d4d" },
            { "NR", "\u2d4f\u2d30\u2d61\u2d54\u2d53" },
            { "NU", "\u2d4f\u2d49\u2d61\u2d49" },
            { "NZ", "\u2d4f\u2d62\u2d53\u2d63\u2d49\u2d4d\u2d30\u2d4f\u2d37\u2d30" },
            { "OM", "\u2d44\u2d53\u2d4e\u2d30\u2d4f" },
            { "PA", "\u2d31\u2d30\u2d4f\u2d30\u2d4e\u2d30" },
            { "PE", "\u2d31\u2d49\u2d54\u2d53" },
            { "PF", "\u2d31\u2d53\u2d4d\u2d49\u2d4f\u2d49\u2d63\u2d62\u2d30 \u2d5c\u2d30\u2d3c\u2d54\u2d30\u2d4f\u2d59\u2d49\u2d59\u2d5c" },
            { "PG", "\u2d31\u2d30\u2d31\u2d61\u2d30 \u2d56\u2d49\u2d4f\u2d62\u2d30 \u2d5c\u2d30\u2d4e\u2d30\u2d62\u2d4f\u2d53\u2d5c" },
            { "PH", "\u2d3c\u2d49\u2d4d\u2d49\u2d31\u2d31\u2d49\u2d4f" },
            { "PK", "\u2d31\u2d30\u2d3d\u2d49\u2d59\u2d5c\u2d30\u2d4f" },
            { "PL", "\u2d31\u2d53\u2d4d\u2d53\u2d4f\u2d62\u2d30" },
            { "PM", "\u2d59\u2d30\u2d4f\u2d31\u2d62\u2d49\u2d54 \u2d37 \u2d4e\u2d49\u2d3d\u2d4d\u2d53\u2d4f" },
            { "PN", "\u2d31\u2d49\u2d5c\u2d3d\u2d30\u2d62\u2d54\u2d4f" },
            { "PR", "\u2d31\u2d53\u2d54\u2d5c\u2d53 \u2d54\u2d49\u2d3d\u2d53" },
            { "PS", "\u2d30\u2d33\u2d4e\u2d4e\u2d30\u2d39 \u2d4f \u2d5c\u2d30\u2d33\u2d53\u2d5c \u2d37 \u2d56\u2d63\u2d63\u2d30" },
            { "PT", "\u2d31\u2d55\u2d5f\u2d47\u2d49\u2d63" },
            { "PW", "\u2d31\u2d30\u2d4d\u2d30\u2d61" },
            { "PY", "\u2d31\u2d30\u2d54\u2d30\u2d33\u2d61\u2d30\u2d62" },
            { "QA", "\u2d47\u2d30\u2d5c\u2d30\u2d54" },
            { "RE", "\u2d54\u2d49\u2d62\u2d53\u2d4f\u2d62\u2d53\u2d4f" },
            { "RO", "\u2d54\u2d53\u2d4e\u2d30\u2d4f\u2d62\u2d30" },
            { "RS", "\u2d59\u2d49\u2d54\u2d31\u2d62\u2d30" },
            { "RU", "\u2d54\u2d53\u2d59\u2d62\u2d30" },
            { "RW", "\u2d54\u2d61\u2d30\u2d4f\u2d37\u2d30" },
            { "SA", "\u2d59\u2d59\u2d30\u2d44\u2d53\u2d37\u2d49\u2d62\u2d30" },
            { "SB", "\u2d5c\u2d49\u2d33\u2d63\u2d49\u2d54\u2d49\u2d4f \u2d4f \u2d59\u2d30\u2d4d\u2d53\u2d4e\u2d30\u2d4f" },
            { "SC", "\u2d59\u2d59\u2d49\u2d5b\u2d49\u2d4d" },
            { "SD", "\u2d59\u2d59\u2d53\u2d37\u2d30\u2d4f" },
            { "SE", "\u2d59\u2d59\u2d61\u2d49\u2d37" },
            { "SG", "\u2d59\u2d4f\u2d56\u2d30\u2d3c\u2d53\u2d54\u2d30" },
            { "SH", "\u2d59\u2d30\u2d4f\u2d5c\u2d49\u2d4d\u2d49\u2d4f" },
            { "SI", "\u2d59\u2d4d\u2d53\u2d3c\u2d49\u2d4f\u2d62\u2d30" },
            { "SK", "\u2d59\u2d4d\u2d53\u2d3c\u2d30\u2d3d\u2d62\u2d30" },
            { "SL", "\u2d59\u2d59\u2d49\u2d54\u2d30\u2d4d\u2d62\u2d53\u2d4f" },
            { "SM", "\u2d59\u2d30\u2d4f\u2d4e\u2d30\u2d54\u2d49\u2d4f\u2d53" },
            { "SN", "\u2d59\u2d59\u2d49\u2d4f\u2d49\u2d33\u2d30\u2d4d" },
            { "SO", "\u2d5a\u2d5a\u2d53\u2d4e\u2d30\u2d4d" },
            { "SR", "\u2d59\u2d53\u2d54\u2d49\u2d4f\u2d30\u2d4e" },
            { "SS", "\u2d59\u2d59\u2d53\u2d37\u2d30\u2d4f \u2d4f \u2d49\u2d3c\u2d3c\u2d53\u2d59" },
            { "ST", "\u2d59\u2d30\u2d61\u2d5f\u2d53\u2d4e\u2d49 \u2d37 \u2d31\u2d54\u2d30\u2d4f\u2d59\u2d49\u2d31" },
            { "SV", "\u2d59\u2d30\u2d4d\u2d3c\u2d30\u2d37\u2d53\u2d54" },
            { "SY", "\u2d59\u2d53\u2d54\u2d62\u2d30" },
            { "SZ", "\u2d59\u2d61\u2d30\u2d63\u2d49\u2d4d\u2d30\u2d4f\u2d37\u2d30" },
            { "TC", "\u2d5c\u2d49\u2d33\u2d63\u2d49\u2d54\u2d49\u2d4f \u2d4f \u2d5c\u2d53\u2d54\u2d3d\u2d62\u2d30 \u2d37 \u2d3d\u2d30\u2d62\u2d3d" },
            { "TD", "\u2d5c\u2d5b\u2d30\u2d37" },
            { "TG", "\u2d5f\u2d53\u2d33\u2d53" },
            { "TH", "\u2d5f\u2d30\u2d62\u2d4d\u2d30\u2d4f\u2d37" },
            { "TJ", "\u2d5c\u2d30\u2d37\u2d4a\u2d30\u2d3d\u2d49\u2d59\u2d5c\u2d30\u2d4f" },
            { "TK", "\u2d5f\u2d53\u2d3d\u2d4d\u2d30\u2d61" },
            { "TL", "\u2d5c\u2d49\u2d4e\u2d53\u2d54 \u2d4f \u2d4d\u2d47\u2d31\u2d4d\u2d5c" },
            { "TM", "\u2d5c\u2d53\u2d54\u2d3d\u2d4e\u2d30\u2d4f\u2d59\u2d5c\u2d30\u2d4f" },
            { "TN", "\u2d5c\u2d53\u2d4f\u2d59" },
            { "TO", "\u2d5f\u2d53\u2d4f\u2d33\u2d30" },
            { "TR", "\u2d5c\u2d53\u2d54\u2d3d\u2d62\u2d30" },
            { "TT", "\u2d5c\u2d54\u2d49\u2d4f\u2d49\u2d37\u2d30\u2d37 \u2d37 \u2d5f\u2d53\u2d31\u2d30\u2d33\u2d53" },
            { "TV", "\u2d5c\u2d53\u2d3c\u2d30\u2d4d\u2d53" },
            { "TW", "\u2d5f\u2d30\u2d62\u2d61\u2d30\u2d4f" },
            { "TZ", "\u2d5f\u2d30\u2d4f\u2d65\u2d30\u2d4f\u2d62\u2d30" },
            { "UA", "\u2d53\u2d3d\u2d54\u2d30\u2d4f\u2d62\u2d30" },
            { "UG", "\u2d53\u2d56\u2d30\u2d4f\u2d37\u2d30" },
            { "US", "\u2d49\u2d61\u2d53\u2d4f\u2d30\u2d3d \u2d4e\u2d53\u2d4f\u2d4f\u2d49\u2d4f \u2d4f \u2d4e\u2d49\u2d54\u2d49\u2d3d\u2d30\u2d4f" },
            { "UY", "\u2d53\u2d54\u2d53\u2d33\u2d61\u2d30\u2d62" },
            { "UZ", "\u2d53\u2d63\u2d31\u2d30\u2d3d\u2d49\u2d59\u2d5c\u2d30\u2d4f" },
            { "VA", "\u2d30\u2d61\u2d30\u2d4f\u2d3d \u2d4f \u2d3c\u2d30\u2d5c\u2d49\u2d3d\u2d30\u2d4f" },
            { "VC", "\u2d59\u2d30\u2d4f\u2d3c\u2d30\u2d4f\u2d59\u2d30\u2d4f \u2d37 \u2d33\u2d54\u2d49\u2d4f\u2d30\u2d37\u2d49\u2d4f" },
            { "VE", "\u2d3c\u2d49\u2d4f\u2d63\u2d61\u2d49\u2d4d\u2d30" },
            { "VG", "\u2d5c\u2d49\u2d33\u2d63\u2d49\u2d54\u2d49\u2d4f \u2d5c\u2d49\u2d4e\u2d33\u2d30\u2d37 \u2d4f \u2d4f\u2d4f\u2d33\u2d4d\u2d49\u2d63" },
            { "VI", "\u2d5c\u2d49\u2d33\u2d63\u2d49\u2d54\u2d49\u2d4f \u2d5c\u2d49\u2d4e\u2d33\u2d30\u2d37 \u2d4f \u2d49\u2d61\u2d53\u2d4f\u2d30\u2d3d \u2d4e\u2d53\u2d4f\u2d4f\u2d49\u2d4f" },
            { "VN", "\u2d3c\u2d49\u2d5c\u2d4f\u2d30\u2d4e" },
            { "VU", "\u2d3c\u2d30\u2d4f\u2d61\u2d30\u2d5f\u2d53" },
            { "WF", "\u2d61\u2d30\u2d4d\u2d49\u2d59 \u2d37 \u2d3c\u2d53\u2d5c\u2d53\u2d4f\u2d30" },
            { "WS", "\u2d59\u2d30\u2d4e\u2d61\u2d30" },
            { "YE", "\u2d62\u2d30\u2d4e\u2d30\u2d4f" },
            { "YT", "\u2d4e\u2d30\u2d62\u2d53\u2d5f" },
            { "ZA", "\u2d30\u2d3c\u2d54\u2d49\u2d47\u2d62\u2d30 \u2d4f \u2d49\u2d3c\u2d3c\u2d53\u2d59" },
            { "ZM", "\u2d63\u2d30\u2d4e\u2d31\u2d62\u2d30" },
            { "ZW", "\u2d63\u2d49\u2d4e\u2d31\u2d30\u2d31\u2d61\u2d49" },
            { "ak", "\u2d5c\u2d30\u2d3d\u2d30\u2d4f\u2d5c" },
            { "am", "\u2d5c\u2d30\u2d4e\u2d40\u2d30\u2d54\u2d49\u2d5c" },
            { "ar", "\u2d5c\u2d30\u2d44\u2d54\u2d30\u2d31\u2d5c" },
            { "be", "\u2d5c\u2d30\u2d31\u2d49\u2d4d\u2d30\u2d54\u2d53\u2d59\u2d5c" },
            { "bg", "\u2d5c\u2d30\u2d31\u2d4d\u2d56\u2d30\u2d54\u2d49\u2d5c" },
            { "bn", "\u2d5c\u2d30\u2d31\u2d4f\u2d56\u2d30\u2d4d\u2d49\u2d5c" },
            { "cs", "\u2d5c\u2d30\u2d5c\u2d5b\u2d49\u2d3d\u2d49\u2d5c" },
            { "de", "\u2d5c\u2d30\u2d4d\u2d49\u2d4e\u2d30\u2d4f\u2d5c" },
            { "el", "\u2d5c\u2d30\u2d33\u2d54\u2d49\u2d33\u2d49\u2d5c" },
            { "en", "\u2d5c\u2d30\u2d4f\u2d33\u2d4d\u2d49\u2d63\u2d5c" },
            { "es", "\u2d5c\u2d30\u2d59\u2d31\u2d4f\u2d62\u2d53\u2d4d\u2d49\u2d5c" },
            { "fa", "\u2d5c\u2d30\u2d3c\u2d53\u2d54\u2d59\u2d49\u2d5c" },
            { "fr", "\u2d5c\u2d30\u2d3c\u2d54\u2d30\u2d4f\u2d59\u2d49\u2d59\u2d5c" },
            { "ha", "\u2d5c\u2d30\u2d40\u2d30\u2d61\u2d59\u2d30\u2d5c" },
            { "hi", "\u2d5c\u2d30\u2d40\u2d49\u2d4f\u2d37\u2d49\u2d5c" },
            { "hu", "\u2d5c\u2d30\u2d40\u2d4f\u2d56\u2d30\u2d54\u2d49\u2d5c" },
            { "id", "\u2d5c\u2d30\u2d4f\u2d37\u2d53\u2d4f\u2d49\u2d59\u2d49\u2d5c" },
            { "ig", "\u2d5c\u2d49\u2d33\u2d31\u2d53\u2d5c" },
            { "it", "\u2d5c\u2d30\u2d5f\u2d30\u2d4d\u2d62\u2d30\u2d4f\u2d5c" },
            { "ja", "\u2d5c\u2d30\u2d4a\u2d30\u2d31\u2d31\u2d53\u2d4f\u2d49\u2d5c" },
            { "jv", "\u2d5c\u2d30\u2d4a\u2d30\u2d31\u2d30\u2d4f\u2d49\u2d5c" },
            { "km", "\u2d5c\u2d30\u2d45\u2d4e\u2d49\u2d54\u2d5c" },
            { "ko", "\u2d5c\u2d30\u2d3d\u2d53\u2d54\u2d49\u2d5c" },
            { "ms", "\u2d5c\u2d30\u2d4e\u2d30\u2d4d\u2d30\u2d61\u2d49\u2d5c" },
            { "my", "\u2d5c\u2d30\u2d31\u2d49\u2d54\u2d4e\u2d30\u2d4f\u2d49\u2d5c" },
            { "ne", "\u2d5c\u2d30\u2d4f\u2d49\u2d31\u2d30\u2d4d\u2d49\u2d5c" },
            { "nl", "\u2d5c\u2d30\u2d40\u2d53\u2d4d\u2d30\u2d4f\u2d37\u2d49\u2d5c" },
            { "pa", "\u2d5c\u2d30\u2d31\u2d4f\u2d4a\u2d30\u2d31\u2d49\u2d5c" },
            { "pl", "\u2d5c\u2d30\u2d31\u2d53\u2d4d\u2d53\u2d4f\u2d49\u2d5c" },
            { "pt", "\u2d5c\u2d30\u2d31\u2d55\u2d5f\u2d47\u2d49\u2d63\u2d5c" },
            { "ro", "\u2d5c\u2d30\u2d54\u2d53\u2d4e\u2d30\u2d4f\u2d49\u2d5c" },
            { "ru", "\u2d5c\u2d30\u2d54\u2d53\u2d59\u2d49\u2d5c" },
            { "rw", "\u2d5c\u2d30\u2d54\u2d53\u2d61\u2d30\u2d4f\u2d37\u2d49\u2d5c" },
            { "so", "\u2d5c\u2d30\u2d59\u2d53\u2d4e\u2d30\u2d4d\u2d49\u2d5c" },
            { "sv", "\u2d5c\u2d30\u2d59\u2d61\u2d49\u2d37\u2d49\u2d5c" },
            { "ta", "\u2d5c\u2d30\u2d5c\u2d30\u2d4e\u2d49\u2d4d\u2d5c" },
            { "th", "\u2d5c\u2d30\u2d5c\u2d30\u2d62\u2d4d\u2d30\u2d4f\u2d37\u2d49\u2d5c" },
            { "tr", "\u2d5c\u2d30\u2d5c\u2d53\u2d54\u2d3d\u2d49\u2d5c" },
            { "uk", "\u2d5c\u2d53\u2d3d\u2d54\u2d30\u2d4f\u2d49\u2d5c" },
            { "ur", "\u2d5c\u2d53\u2d54\u2d37\u2d53\u2d5c" },
            { "vi", "\u2d5c\u2d30\u2d31\u2d49\u2d5c\u2d4f\u2d30\u2d4e\u2d49\u2d5c" },
            { "yo", "\u2d5c\u2d30\u2d62\u2d54\u2d53\u2d31\u2d30\u2d5c" },
            { "zh", "\u2d5c\u2d30\u2d5b\u2d49\u2d4f\u2d61\u2d49\u2d5c" },
            { "zu", "\u2d5c\u2d30\u2d63\u2d53\u2d4d\u2d53\u2d5c" },
            { "zgh", "\u2d5c\u2d30\u2d4e\u2d30\u2d63\u2d49\u2d56\u2d5c" },
            { "key.ca", "\u2d30\u2d59\u2d4e\u2d4d\u2d53\u2d59\u2d59\u2d30\u2d4f" },
            { "key.co", "\u2d30\u2d4f\u2d4e\u2d30\u2d4d\u2d30 \u2d4f \u2d53\u2d59\u2d5c\u2d30\u2d62" },
            { "key.cu", "\u2d30\u2d37\u2d54\u2d49\u2d4e" },
            { "type.ca.coptic", "\u2d30\u2d59\u2d4e\u2d4d\u2d53\u2d59\u2d59\u2d30\u2d4f \u2d30\u2d47\u2d31\u2d5f\u2d49" },
            { "type.ca.islamic", "\u2d30\u2d59\u2d4e\u2d4d\u2d53\u2d59\u2d59\u2d30\u2d4f \u2d4f \u2d4d\u2d49\u2d59\u2d4d\u2d30\u2d4e" },
            { "type.ca.ethiopic", "\u2d30\u2d59\u2d4e\u2d4d\u2d53\u2d59\u2d59\u2d30\u2d4f \u2d4f \u2d49\u2d5c\u2d62\u2d53\u2d31\u2d62\u2d30" },
            { "type.ca.gregorian", "\u2d30\u2d59\u2d4e\u2d4d\u2d53\u2d59\u2d59\u2d30\u2d4f \u2d30\u2d33\u2d54\u2d49\u2d33\u2d53\u2d54" },
        };
        return data;
    }
}
